@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -62,6 +62,7 @@ import org.osgi.framework.FrameworkEvent;
 import org.osgi.framework.FrameworkListener;
 import org.osgi.service.http.HttpService;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.Reloadable;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.exception.OXException;
 import com.openexchange.http.grizzly.GrizzlyConfig;
@@ -69,9 +70,12 @@ import com.openexchange.http.grizzly.GrizzlyExceptionCode;
 import com.openexchange.http.grizzly.service.comet.CometContextService;
 import com.openexchange.http.grizzly.service.comet.impl.CometContextServiceImpl;
 import com.openexchange.http.grizzly.service.http.HttpServiceFactory;
+import com.openexchange.http.grizzly.service.websocket.WebApplicationService;
+import com.openexchange.http.grizzly.service.websocket.impl.WebApplicationServiceImpl;
 import com.openexchange.http.grizzly.threadpool.GrizzlOXExecutorService;
 import com.openexchange.http.requestwatcher.osgi.services.RequestWatcherService;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.startup.SignalStartedService;
 import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.timer.TimerService;
 
@@ -82,8 +86,6 @@ import com.openexchange.timer.TimerService;
  */
 public class GrizzlyActivator extends HousekeepingActivator {
 
-    private volatile OXHttpServer grizzly;
-
     @Override
     protected Class<?>[] getNeededServices() {
         return new Class[] { ConfigurationService.class, RequestWatcherService.class, ThreadPoolService.class, TimerService.class };
@@ -119,7 +121,6 @@ public class GrizzlyActivator extends HousekeepingActivator {
              * create, configure and start server
              */
             final OXHttpServer grizzly = new OXHttpServer();
-            this.grizzly = grizzly;
 
             ServerConfiguration serverConfiguration = grizzly.getServerConfiguration();
             serverConfiguration.setMaxRequestParameters(grizzlyConfig.getMaxRequestParameters());
@@ -165,6 +166,7 @@ public class GrizzlyActivator extends HousekeepingActivator {
 
             if (grizzlyConfig.isWebsocketsEnabled()) {
                 networkListener.registerAddOn(new WebSocketAddOn());
+                registerService(WebApplicationService.class, new WebApplicationServiceImpl());
                 log.info("Enabled WebSockets for Grizzly server.");
             }
 
@@ -176,7 +178,7 @@ public class GrizzlyActivator extends HousekeepingActivator {
 
             grizzly.addListener(networkListener);
             grizzly.start();
-            log.info("Registered Grizzly HttpNetworkListener on host: {} and port: {}", grizzlyConfig.getHttpHost(), Integer.valueOf(grizzlyConfig.getHttpPort()));
+            log.info("Prepared Grizzly HttpNetworkListener on host: {} and port: {}, but not yet started...", grizzlyConfig.getHttpHost(), Integer.valueOf(grizzlyConfig.getHttpPort()));
 
             /*
              * Servicefactory that creates instances of the HttpService interface that grizzly implements. Each distinct bundle that uses
@@ -185,6 +187,11 @@ public class GrizzlyActivator extends HousekeepingActivator {
             registerService(HttpService.class.getName(), new HttpServiceFactory(grizzly, context.getBundle()));
             log.info("Registered OSGi HttpService for Grizzly server.");
 
+            registerService(Reloadable.class, grizzlyConfig);
+
+            // Finally start listeners if server start-up is completed
+            track(SignalStartedService.class, new StartUpTracker(grizzly, grizzlyConfig, context));
+            openTrackers();
         } catch (final Exception e) {
             throw GrizzlyExceptionCode.GRIZZLY_SERVER_NOT_STARTED.create(e, new Object[] {});
         }
@@ -192,18 +199,10 @@ public class GrizzlyActivator extends HousekeepingActivator {
 
     @Override
     protected void stopBundle() throws Exception {
-        final org.slf4j.Logger log = org.slf4j.LoggerFactory.getLogger(GrizzlyActivator.class);
-        log.info("Unregistering services.");
+        org.slf4j.LoggerFactory.getLogger(GrizzlyActivator.class).info("Unregistering services.");
         super.stopBundle();
 
         Services.setServiceLookup(null);
-
-        log.info("Stopping Grizzly.");
-        final OXHttpServer grizzly = this.grizzly;
-        if (null != grizzly) {
-            grizzly.stop();
-            this.grizzly = null;
-        }
     }
 
     /**
