@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,9 @@
 package com.openexchange.http.grizzly.servletfilter;
 
 import java.io.IOException;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Set;
 import javax.servlet.Filter;
 import javax.servlet.FilterChain;
 import javax.servlet.FilterConfig;
@@ -58,14 +61,14 @@ import javax.servlet.ServletRequest;
 import javax.servlet.ServletResponse;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.logging.Log;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.http.grizzly.GrizzlyExceptionCode;
 import com.openexchange.http.grizzly.osgi.Services;
+import com.openexchange.http.grizzly.util.RequestTools;
 import com.openexchange.http.requestwatcher.osgi.services.RequestRegistryEntry;
 import com.openexchange.http.requestwatcher.osgi.services.RequestWatcherService;
-import com.openexchange.java.StringAllocator;
+import com.openexchange.log.LogProperties;
 
 /**
  * {@link RequestReportingFilter} - Add incoming requests to the RequestWatcherService so we can track and interrupt long running requests.
@@ -75,19 +78,14 @@ import com.openexchange.java.StringAllocator;
  */
 public class RequestReportingFilter implements Filter {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(RequestReportingFilter.class);
-
-    // properties of long running eas requests
-    private static final String EAS_URI = "/Microsoft-Server-ActiveSync";
-
-    private static final String EAS_CMD = "Cmd";
-
-    private static final String EAS_PING = "Ping";
-
-    private static final String DRIVE_URI = "/ajax/drive";
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(RequestReportingFilter.class);
 
     private final boolean isFilterEnabled;
 
+    private final Set<String> ignoredEasCommands;
+
+    private final Set<String> ignoredUsmCommands;
+
     /**
      * Initializes a new {@link RequestReportingFilter}.
      *
@@ -99,6 +97,12 @@ public class RequestReportingFilter implements Filter {
             throw GrizzlyExceptionCode.NEEDED_SERVICE_MISSING.create(ConfigurationService.class.getSimpleName());
         }
         this.isFilterEnabled = configService.getBoolProperty("com.openexchange.server.requestwatcher.isEnabled", true);
+
+        List<String> ignoreEas = configService.getProperty("com.openexchange.requestwatcher.eas.ignore.cmd", "ping,sync", ",");
+        this.ignoredEasCommands = new HashSet<String>(ignoreEas);
+
+        List<String> ignoreUsm = configService.getProperty("com.openexchange.requestwatcher.usm.ignore.path", "/syncupdate", ",");
+        this.ignoredUsmCommands = new HashSet<String>(ignoreUsm);
     }
 
     @Override
@@ -107,57 +111,49 @@ public class RequestReportingFilter implements Filter {
     }
 
     @Override
-    public void doFilter(final ServletRequest request, final ServletResponse response, final FilterChain chain) throws IOException, ServletException {
+    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
         if (isFilterEnabled) {
-            final HttpServletRequest httpServletRequest = (HttpServletRequest) request;
-            final HttpServletResponse httpServletResponse = (HttpServletResponse) response;
-            if (isLongRunning(httpServletRequest)) { // Do not track long running requests
+            RequestWatcherService requestWatcher = Services.optService(RequestWatcherService.class);
+            if (requestWatcher == null) {
+                // Request watcher is enabled but service is missing, bundle not started etc ..
+                org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(RequestReportingFilter.class);
+                logger.debug("{} is not available. Unable to watch this request.", RequestWatcherService.class.getSimpleName());
                 chain.doFilter(request, response);
             } else {
-                final RequestWatcherService requestWatcher = Services.optService(RequestWatcherService.class);
-                // Request watcher is enabled but service is missing, bundle not started etc ..
-                if (requestWatcher == null) {
-                    if (LOG.isDebugEnabled()) {
-                        LOG.debug(new StringAllocator(RequestWatcherService.class.getSimpleName()).append(" is not available. Unable to watch this request.").toString());
-                    }
-                    chain.doFilter(httpServletRequest, httpServletResponse);
+                HttpServletRequest httpRequest = (HttpServletRequest) request;
+                if (isLongRunning(httpRequest) || isIgnored(httpRequest)) {
+                    // Do not track long running requests
+                    chain.doFilter(request, response);
                 } else {
-                    final RequestRegistryEntry requestRegistryEntry = requestWatcher.registerRequest(httpServletRequest, httpServletResponse, Thread.currentThread());
+                    HttpServletResponse httpResponse = (HttpServletResponse) response;
+                    RequestRegistryEntry entry = requestWatcher.registerRequest(httpRequest, httpResponse, Thread.currentThread(), LogProperties.getPropertyMap());
                     try {
                         // Proceed processing
                         chain.doFilter(request, response);
-
-                        // Debug duration
-                        if (LOG.isDebugEnabled()) {
-                            LOG.debug(new StringAllocator("Request took ").append(requestRegistryEntry.getAge()).append("ms ").append(" for URL: ").append(
-                                httpServletRequest.getRequestURL()).toString());
-                        }
                     } finally {
                         // Remove request from watcher after processing finished
-                        requestWatcher.unregisterRequest(requestRegistryEntry);
+                        requestWatcher.unregisterRequest(entry);
                     }
                 }
             }
-        } else { // Filter is not enabled
+        } else {
+            // Filter is not enabled
             chain.doFilter(request, response);
         }
     }
 
+
+    private boolean isIgnored(HttpServletRequest httpRequest) {
+        return RequestTools.isIgnoredEasRequest(httpRequest, ignoredEasCommands) || RequestTools.isIgnoredUsmRequest(httpRequest, ignoredUsmCommands);
+    }
+
     @Override
     public void destroy() {
         // nothing to do here
     }
 
-    private boolean isLongRunning(final HttpServletRequest httpServletRequest) {
-        return isDriveRequest(httpServletRequest) || isEASRequest(httpServletRequest);
-    }
-
-    private final boolean isDriveRequest(final HttpServletRequest httpServletRequest) {
-        return DRIVE_URI.equals(httpServletRequest.getRequestURI());
-    }
-
-    private final boolean isEASRequest(final HttpServletRequest httpServletRequest) {
-        return EAS_URI.equals(httpServletRequest.getRequestURI()) && EAS_PING.equals(httpServletRequest.getParameter(EAS_CMD));
+    private boolean isLongRunning(HttpServletRequest request) {
+        return RequestTools.isDriveRequest(request);
     }
 
 }
